@@ -219,7 +219,14 @@ class Arlo(object):
             headers=headers,
             raw=True
         )
-        email_factor_id = next(i for i in factors_body['data']['items'] if i['factorType'] == 'EMAIL' and i['factorRole'] == "PRIMARY")['factorId']
+        email_factor = next((i for i in factors_body['data']['items'] if i['factorType'] == 'EMAIL' and i['factorRole'] == "PRIMARY"), None)
+        if email_factor is None:
+            email_factor = next((i for i in factors_body['data']['items'] if i['factorType'] == 'EMAIL' and i['factorRole'] == "SECONDARY"), None)
+
+        if email_factor is None:
+            raise Exception('No EMAIL MFA method registered with the account.')
+
+        email_factor_id = email_factor['factorId']
 
         # Start factor auth
         start_auth_body = self.request.post(
@@ -231,7 +238,7 @@ class Arlo(object):
         factor_auth_code = start_auth_body['data']['factorAuthCode']
 
         # search for MFA token in latest emails
-        pattern = '\d{6}'
+        pattern = r'\d{6}'
         code = None
         service = build('gmail', 'v1', credentials = self.google_credentials)
 
@@ -1755,4 +1762,4 @@ class Arlo(object):
 
     def GetCvrPlaylist(self, camera, fromDate, toDate):
         """ This function downloads a Cvr Playlist file for the period fromDate to toDate. """
-        return self.request.get(f'https://{self.BASE_URL}/hmsweb/users/devices/'+camera.get('deviceId')+'/playlist?fromDate='+fromDate+'&toDate='+toDate)
+        return self.request.get(f'https://{self.BASE_URL}/hmsweb/users/devices/'+camera.get('uniqueId')+'/playlist?fromDate='+fromDate+'&toDate='+toDate)
